<?php

namespace App\Http\Controllers\Admin;

use App\Models\Brand;
use App\Models\Category;
use App\Models\Campaign;
use App\Models\CampaignContext;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\File;

class CategoriesController extends Controller
{
    public function getCategories($brandId)
    {
        $categories = Category::where('brand_id', $brandId)->get();
        return response()->json($categories);
    }

    public function getCampaigns($categoryId)
    {
        $campaigns = Campaign::where('category_id', $categoryId)->get();
        return response()->json($campaigns);
    }

    public function index(Request $request)
    {
        // Get the search query
        $search = $request->input('search');

        // Fetch categories with optional search and pagination
        $categories = Category::with('brand')
            ->when($search, function ($query, $search) {
                return $query->where('name', 'LIKE', "%{$search}%")
                            ->orWhereHas('brand', function ($query) use ($search) {
                                $query->where('name', 'LIKE', "%{$search}%");
                            });
            })
            ->paginate(10);

        return view('Admin.category.index', compact('categories', 'search'));
    }
    
    public function add()
    {
        $brands = Brand::all();
        return view('Admin.category.add', compact('brands'));
    }
    public function insert(Request $request)
    {
        $request->validate([
            'category_name' => 'required|string|max:255',
            'brand_id' => 'required|exists:brands,id',
        ]);

        $slug = Str::slug($request->input('category_name'));

        // Create the category
        Category::create([
            'name' => $request->category_name,
            'slug' => $slug,
            'brand_id' => $request->brand_id,
        ]);

        return redirect('/categories')->with('status', "Category Added Successfully");
    }

    public function edit($id)
    {
        $category = Category::find($id);
        $brands = Brand::all();
        return view('Admin.category.edit', compact('category', 'brands'));
    }

    public function update(Request $request,  $id)
    {
        // Validate the incoming request data
        $request->validate([
            'category_name' => 'required|string|max:255',
            'brand_id' => 'required|exists:brands,id', // Ensure the brand ID exists
        ]);

        // Find the category
        $category = Category::findOrFail($id);

        // Generate the slug from the category name
        $slug = Str::slug($request->input('category_name'));

        // Check if the slug already exists and modify it if necessary
        $originalSlug = $slug;
        $count = 1;

        while (Category::where('slug', $slug)->where('id', '!=', $id)->exists()) {
            $slug = $originalSlug . '-' . $count; // Append a number to the slug
            $count++;
        }

        // Update the category
        $category->update([
            'name' => $request->input('category_name'),
            'slug' => $slug,
            'brand_id' => $request->input('brand_id'),
        ]);

        return redirect()->route('categories.index')->with('status', 'Category updated successfully!');
    }

    public function delete($id)
    {
        $category = Category::find($id);
        if ($category->image) {
            $path  = 'upload/category/' . $category->image;
            if (File::exists($path)) {
                File::delete($path);
            }
        }
        $category->delete();
        return redirect('/categories')->with('status', "Category deleted Successfully");
    }

    public function getCategoriesByBrand(Request $request)
    {
    $brandId = $request->query('brand_id');
    $categories = Category::where('brand_id', $brandId)->get(); // Adjust the logic as per your database structure
    return response()->json($categories);
    }

    public function getCampaignsByCategoryId($categoryId)
{
    $campaigns = CampaignContext::with('campaign')->where('is_global',0)->where('category_id', $categoryId)->get();
    return response()->json($campaigns);
}
}
