<?php

namespace App\Http\Controllers;

use App\Models\CampaignContextProduct;
use App\Models\CampaignContext;
use App\Models\Product;
use App\Models\Brand;
use App\Models\Category;
use Illuminate\Validation\Rule;
use App\Models\Campaign;
use Illuminate\Http\Request;

class CampaignContextProductController extends Controller
{
    public function index(Request $request)
    {
        // Get the search query from the request
        $search = $request->input('search');
    
        // Fetch campaign context products with optional search and pagination
        $campaignContextProducts = CampaignContextProduct::with(['product', 'campaignContext.brand', 'campaignContext.category'])
            ->whereHas('campaignContext', function ($query) {
                $query->where('is_global', 0);
            })
            ->when($search, function ($query, $search) {
                $query->whereHas('product', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                })
                ->orWhereHas('campaignContext.brand', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                })
                ->orWhereHas('campaignContext.category', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                });
            })
            ->paginate(10);
    
        return view('Admin.campaign-context-product.index', compact('campaignContextProducts', 'search'));
    }
    

    public function homeIndex(Request $request)
    {
        // Get the search query from the request
        $search = $request->input('search');

        // Fetch campaign context products with optional search and pagination
        $campaignContextProducts = CampaignContextProduct::with(['product', 'campaignContext.brand', 'campaignContext.category'])
            ->whereHas('campaignContext', function ($query) {
                $query->where('is_global', 0);
            })
            ->when($search, function ($query, $search) {
                $query->whereHas('product', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                })
                ->orWhereHas('campaignContext.brand', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                })
                ->orWhereHas('campaignContext.category', function ($q) use ($search) {
                    $q->where('name', 'LIKE', "%{$search}%");
                });
            })
            ->paginate(10);

        return view('Admin.home-context-product.index', compact('campaignContextProducts', 'search'));
    }

    public function create()
    {
        $brands = Brand::all();
        $categories = Category::all();
        $campaigns = Campaign::all();
        $campaignContexts = CampaignContext::where('is_global',0)->get();
        $products = Product::all();
        return view('Admin.campaign-context-product.create', compact('campaignContexts', 'products','brands','categories','campaigns'));
    }

    public function homeCreate()
    {
        $campaignContexts = CampaignContext::with('campaign')->where('is_global',1)->get();
        $products = Product::all();
        return view('Admin.home-context-product.create', compact('campaignContexts', 'products'));
    }

    public function homeStore(Request $request)
    {
        $data = $request->validate([
        'campaign_context_id' => 'required',
        'product_id' => [
        'required',
                Rule::unique('campaign_context_products')
                    ->where('campaign_context_id', $request->campaign_context_id)
            ],
        ]);

        
        CampaignContextProduct::create($data);
        return redirect('/home-campaign-context-product')->with('status', 'Product Added to Home Campaign Successfully');
    }

    public function store(Request $request)
    {
        $data = $request->validate([
            'campaign_context_id' => 'required',
           'product_id' => [
        'required',
                Rule::unique('campaign_context_products')
                    ->where('campaign_context_id', $request->campaign_context_id)
            ],
            [
                'product_id.unique'=>'This Product is already added to the section',
            ]
        ]);
        
        CampaignContextProduct::create($data);
        return redirect('/campaign-context-product')->with('status', 'Product Added to Campaign Successfully');
    }

    public function edit($id)
    {
        $brands = Brand::all();
        $categories = Category::all();
        $campaigns = Campaign::all();
        $campaignContextProduct = CampaignContextProduct::findOrFail($id);
        $campaignContexts = CampaignContext::all();
        $products = Product::all();
        return view('Admin.campaign-context-product.edit', compact('campaignContextProduct', 'campaignContexts', 'products','brands','categories','campaigns'));
    }

    public function update(Request $request, $id)
    {
        $campaignContextProduct = CampaignContextProduct::findOrFail($id);
        $data = $request->validate([
            'campaign_context_id' => 'required',
            'product_id' => 'required',
        ]);
        
        $campaignContextProduct->update($data);
        return redirect('/campaign-context-product')->with('status', 'Product updated from  Campaign Successfully');
    }

    public function destroy($id)
    {
        $campaignContextProduct = CampaignContextProduct::findOrFail($id);
        $campaignContextProduct->delete();
        return redirect('/campaign-context-product')->with('status', 'Product deleted from  Campaign Successfully');
    }
}
